# bpm-ai-inference

Extension to bpm-ai project for local AI inference.

## Install platform specific dependencies
### Linux
Install PyTorch (with CUDA GPU support) and spaCy:
```bash
$ pip install -r requirements.txt
```
or CPU-only:
```bash
$ pip install -r requirements.linux-cpu.txt
```

### Apple Silicon:
```bash
$ pip install -r requirements.apple.txt
```

## Install from PyPi
```bash
$ pip install bpm-ai-inference
```

## License

This project is developed under

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

due to dependency licenses.

## Sponsors and Customers

[![sponsored](https://img.shields.io/badge/sponsoredBy-Holisticon-red.svg)](https://holisticon.de/)
